@@ -1051,7 +1051,7 @@ set_png_tags(i_img *im, png_structp png_ptr, png_infop info_ptr) {
 	}
 
 	for (k = 0; k < key_size; ++k) {
-	  if (key[k] < 32 || (key[k] > 126 && key[k] < 161)) {
+	  if (key[k] < 32 || ((unsigned char)key[k] > 126 && (unsigned char)key[k] < 161)) {
 	    i_push_errorf(0, "tag %s may only contain Latin1 characters 32-126, 161-255", tag_name);
 	    return 0;
 	  }
